function [] = Neurosporaf7_Gui()
    // Default simulation parameters
	param = [];
	param.A   = 0.0000462010; 
    param.Ap = 0.566108;
    param.S1 = 9.22739;
    param.S3 = 0.000000136553;
    param.S4 = 9.07295;
    param.D1 = 1.35911;
    param.D3 = 0.223231;
    param.C1 = 0.0545178;
    param.L1 = 59.7062;
    param.L3 = 0.798222;
    param.D4 = 0.00000947792;
    param.D6 = 0.159737;
    param.D7 = 0.192918;
    param.D8 = 0.00285475;
    param.P = 3.55829;
    param.vp = 0.120699;
    param.u1 = 0.0124268;
    param.f0 = 0.692213;
    param.n = 4;
    param.C2 = 1.66501;
    param.m = 4;
    param.E2 = param.vp*param.C2;
    param.fG = 0.69622082;
    param.v1 = param.S1*param.u1;

	// Simulation data
	// Time variables
	sim = [];
	sim.Tbegin = 0;          // Initial time
	sim.Tend   = 200;          // Final time
	sim.Tstep  = 0.01;          // Time step
	// Initial conditions
	sim.a0 = 0.00400782;
    sim.b0 = 0.181388;
    sim.c0 = 1.37307;
    sim.d0 = 0.0000663227;
    sim.e0 = 0.0000362815;
    sim.g0 = 0.212505;
    sim.h0 = 0.0000000252030;             

	// global default data
	global gparam gsim pf sf;
	gparam = param;
	gsim = sim;
	// param and sim fields
	pf = fieldnames(gparam);	// param fields
	sf = fieldnames(gsim);		// sim fields
	
	// ----------------------------
	// Step : Empty window creation
	// ----------------------------
	
	// Global window parameters
	global margin_x margin_y;
	global frame_w frame_h plot_w plot_h;

	// Window Parameters initialization
	frame_w = 300; frame_h = 550;		// Frame width and height
	plot_w = 600; plot_h = frame_h;	// Plot width and heigh
	margin_x = 15; margin_y = 15;		// Horizontal and vertical margin for elements
	defaultfont = "arial"; 			// Default Font
	axes_w = 3*margin_x + frame_w + plot_w;	// axes width
	axes_h = 2*margin_y + frame_h;          	// axes height (100 => toolbar height)
	demo_lhy = scf(100001);			// Create window with id=100001 and make it the current one
	
	// Background and text
	demo_lhy.background      = -2;
	demo_lhy.figure_position = [100 100];
	demo_lhy.figure_name     = gettext("Biological Clock of Neurospora Crassa");
	
	// Change dimensions of the figure
	demo_lhy.axes_size = [axes_w axes_h];
	
	// ------------------
	// Step : Window menu
	// ------------------
	
	// Remove Scilab graphics menus & toolbar
	delmenu(demo_lhy.figure_id,gettext("&File"));
	delmenu(demo_lhy.figure_id,gettext("&Tools"));
	delmenu(demo_lhy.figure_id,gettext("&Edit"));
	delmenu(demo_lhy.figure_id,gettext("&?"));
	toolbar(demo_lhy.figure_id,"off");

	// New menu
	h1 = uimenu("parent",demo_lhy, "label",gettext("File"));
	h2 = uimenu("parent",demo_lhy, "label",gettext("About"));
	
	// Populate menu: file
	uimenu("parent",h1, "label",gettext("Close"), "callback", "demo_lhy=get_figure_handle(100001);delete(demo_lhy);", "tag","close_menu");
	
	// Populate menu: about
	uimenu("parent",h2, "label",gettext("About"), "callback","LHY_About();");
	// Sleep to guarantee a better display (avoiding to see a sequential display)
	sleep(500);
   
	// ---------------------
	// Step : Create a frame
	// ---------------------
	
	// Frames creation [LHY parameters]
	my_frame = uicontrol("parent",demo_lhy, "relief","groove", ...
		"style","frame", "units","pixels", ...
		"position",[ margin_x margin_y frame_w frame_h], ...
		"horizontalalignment","center", "background",[1 1 1], ...
		"tag","frame_control");

	// Frame title
	my_frame_title = uicontrol("parent",demo_lhy, "style","text", ...
		"string","Biological Clock parameters", "units","pixels", ...
		"position",[30+margin_x margin_y+frame_h-10 frame_w-60 20], ...
		"fontname",defaultfont, "fontunits","points", ...
		"fontsize",16, "horizontalalignment","center", ...
		"background",[1 1 1], "tag","title_frame_control");
	// -------------------------
	// Step : Populate the frame
	// -------------------------
	// Adding model parameters
	guih1 = frame_w;
	guih1o = 240;
	// ordered list of labels
	labels1 = ["v1", "D1", "C1"];
	// ordered list of default values
	values1 = [param.S1*param.u1, 1.35911, 0.0545178];
	// positioning
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels1,2)
		uicontrol("parent",demo_lhy, "style","text",...
			"string",labels1(k), "position",[l1,guih1-k*20+guih1o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry1(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values1(k)), "position",[l3,guih1-k*20+guih1o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels1(k));
	end
	// Adding simulation paramters
	guih2 = 240;
	guih2o = 80;
	labels2 = ["Tbegin", "Tend", "Tstep"];
	values2 = ["0", "200", "0.01"];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels2,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels2(k), "position",[l1,guih2-k*20+guih2o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
	
		guientry2(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",values2(k), "position",[l3,guih2-k*20+guih2o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels2(k));
	end
	// Adding initial conditions
	guih3 = 150;
	guih3o = 80;
	labels3 = ["f1o", "f2o", "f3o", "f4o", "f5o", "f6o", "f7o"];
	values3 = [0.00400782, 0.181388, 1.37307, 0.0000663227, 0.0000362815, 0.212505, 0.0000000252030];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels3,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels3(k), "position",[l1,guih3-k*20+guih3o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry3(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values3(k)), "position",[l3,guih3-k*20+guih3o,180,20], ...
			"horizontalalignment","left", "fontsize",14,...
			"background",[.9 .9 .9], "tag",labels3(k));
	end

	// Adding button
	huibutton = uicontrol(demo_lhy, "style","pushbutton", ...
		"Position",[110 60 100 20], "String","Compute", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",14, ...
		"Callback","syscompute");

	// Compute solution
	sol = solvingProblem(param, sim);

	// Redraw window
	drawlater();
	newaxes();
	displayProblem(sol);
	drawnow();

endfunction

function syscompute
	// retrive data
	param = [];
	v1 = findobj("tag", "v1");		param.v1 = evstr(v1.string);
	D1 = findobj("tag", "D1");		param.D1 = evstr(D1.string);
	C1 = findobj("tag", "C1");		param.C1 = evstr(C1.string);

	sim = [];
	Tbegin = findobj("tag", "Tbegin");sim.Tbegin = evstr(Tbegin.string);
	Tend = findobj("tag", "Tend");	sim.Tend = evstr(Tend.string);
	Tstep = findobj("tag", "Tstep");	sim.Tstep = evstr(Tstep.string);
	a0 = findobj("tag", "f1o");			sim.a0 = evstr(a0.string);
	b0 = findobj("tag", "f2o");			sim.b0 = evstr(b0.string);
	c0 = findobj("tag", "f3o");			sim.c0 = evstr(c0.string);
	d0 = findobj("tag", "f4o");			sim.d0 = evstr(d0.string);
	e0 = findobj("tag", "f5o");			sim.e0 = evstr(e0.string);
	g0 = findobj("tag", "f6o");			sim.g0 = evstr(g0.string);
	h0 = findobj("tag", "f7o");			sim.h0 = evstr(h0.string);

	// Update fields
	updateFields(param, sim);
	
	// Compute solution
	sol = solvingProblem(param, sim);

	// Redraw window
	drawlater();
	my_plot_axes = gca();
	my_plot_axes.title.text = "Behaviour of Biological Clock Species";
	newaxes();
	displayProblem(sol);
	drawnow();
endfunction

function sol = solvingProblem(param, sim)
	// Compute the solution
	sol = struct();

	// Assign ODE solver data
	y0 = [sim.a0;sim.b0;sim.c0;sim.d0;sim.e0;sim.g0;sim.h0];
	t0 = sim.Tbegin;
	t = sim.Tbegin:sim.Tstep:(sim.Tend+100*%eps);
	f = Neurosporaf7_System;

	// Solving the system
	sol.abcdegh = ode("stiff", y0, t0, t, f);
	sol.t = t;
endfunction


function displayProblem(solh)   
	// Fetching solution
	abcdegh = sol.abcdegh;
	t = sol.t;
	a = abcdegh(1,:); b = abcdegh(2,:); c = abcdegh(3,:); d = abcdegh(4,:); e = abcdegh(5,:); g = abcdegh(6,:); h = abcdegh(7,:);

delete(gca());
plot(t,abcdegh(7,:));
xlabel('Time')
ylabel('Amount ur0 species')
set(gca(),"auto_clear","on");
	my_plot_axes = gca();
	my_plot_axes.title.font_size = 5;
	my_plot_axes.axes_bounds = [1/3,0,2/3,1];
	my_plot_axes.title.text = "Behaviour of Biological Clock Species";
endfunction

function LHY_About()
    msg = msprintf(gettext("Graf menunjukkan simulasi Biological Clock of Neurospora Crassa di mana jumlah spesis f1 lawan masa"));
	messagebox(msg, gettext("About"), "info", "modal");
endfunction

function updateFields(param, sim)
	global gparam gsim pf sf
	
	// Loop over gparam/param elements
	for i=1:size(pf,1)
		// Get current field
		cf = pf(i);
		// check if they are different
		checkequal = 0;
		if(abs(gparam(cf)-param(cf))<= 1e-12) then
			checkequal = 1;
		end
		// Find object
		obj = findobj("tag", cf);
		if(isempty(obj)) then
			// object not found, skip, some problems?
			continue;
		end
		// Colorize
		if(~checkequal) then
			// Object is modified: use new color
			obj.BackgroundColor = [0.98 0.83 0.71];
		else
			// Object is not modified: use default color
			obj.BackgroundColor = [.9 .9 .9];
		end
	end
	
	// The same code for the field gsim/sim
	for i=1:size(sf,1)
		// Get current field
		cf = sf(i);
		// check if they are differents
		checkequal = 0;
		if(abs(gsim(cf)-sim(cf))<= 1e-12) then
			checkequal = 1;
		end
		// Find object
		obj = findobj("tag", cf);
		if(isempty(obj)) then
			// object not found, skip, some problems?
			continue;
		end
		// Colorize
		if(~checkequal) then
			// Object is modified: use new color
			obj.BackgroundColor = [0.98 0.83 0.71];
		else
			// Object is not modied: use default color
			obj.BackgroundColor = [.9 .9 .9];
		end
	end
endfunction
