function [] = RepressilatorB2_Gui()
    // Default simulation parameters
	param = [];
    param.alpha0 = 1;
    param.alpha = 1000;
    param.n = 2.0;
    param.beta = 5;
	// Simulation data
	// Time variables
	sim = [];
	sim.Tbegin = 0;          // Initial time
	sim.Tend   = 15;          // Final time
	sim.Tstep  = 0.1;          // Time step
	// Initial conditions
	sim.A0 = 0;             
	sim.B0 = 1;            
	sim.C0 = 0;
    sim.D0 = 2;
    sim.E0 = 0;
    sim.F0 = 5;

	// global default data
	global gparam gsim pf sf;
	gparam = param;
	gsim = sim;
	// param and sim fields
	pf = fieldnames(gparam);	// param fields
	sf = fieldnames(gsim);		// sim fields
	
	// ----------------------------
	// Step : Empty window creation
	// ----------------------------
	
	// Global window parameters
	global margin_x margin_y;
	global frame_w frame_h plot_w plot_h;

	// Window Parameters initialization
	frame_w = 300; frame_h = 550;		// Frame width and height
	plot_w = 600; plot_h = frame_h;	// Plot width and heigh
	margin_x = 15; margin_y = 15;		// Horizontal and vertical margin for elements
	defaultfont = "arial"; 			// Default Font
	axes_w = 3*margin_x + frame_w + plot_w;	// axes width
	axes_h = 2*margin_y + frame_h;          	// axes height (100 => toolbar height)
	demo_lhy = scf(100001);			// Create window with id=100001 and make it the current one
	
	// Background and text
	demo_lhy.background      = -2;
	demo_lhy.figure_position = [100 100];
	demo_lhy.figure_name     = gettext("Biological Circuit of Repressilator");
	
	// Change dimensions of the figure
	demo_lhy.axes_size = [axes_w axes_h];
	
	// ------------------
	// Step : Window menu
	// ------------------
	
	// Remove Scilab graphics menus & toolbar
	delmenu(demo_lhy.figure_id,gettext("&File"));
	delmenu(demo_lhy.figure_id,gettext("&Tools"));
	delmenu(demo_lhy.figure_id,gettext("&Edit"));
	delmenu(demo_lhy.figure_id,gettext("&?"));
	toolbar(demo_lhy.figure_id,"off");

	// New menu
	h1 = uimenu("parent",demo_lhy, "label",gettext("File"));
	h2 = uimenu("parent",demo_lhy, "label",gettext("About"));
	
	// Populate menu: file
	uimenu("parent",h1, "label",gettext("Close"), "callback", "demo_lhy=get_figure_handle(100001);delete(demo_lhy);", "tag","close_menu");
	
	// Populate menu: about
	uimenu("parent",h2, "label",gettext("About"), "callback","LHY_About();");
	// Sleep to guarantee a better display (avoiding to see a sequential display)
	sleep(500);
   
	// ---------------------
	// Step : Create a frame
	// ---------------------
	
	// Frames creation [LHY parameters]
	my_frame = uicontrol("parent",demo_lhy, "relief","groove", ...
		"style","frame", "units","pixels", ...
		"position",[ margin_x margin_y frame_w frame_h], ...
		"horizontalalignment","center", "background",[1 1 1], ...
		"tag","frame_control");

	// Frame title
	my_frame_title = uicontrol("parent",demo_lhy, "style","text", ...
		"string","Repressilator oscillatory parameters", "units","pixels", ...
		"position",[30+margin_x margin_y+frame_h-10 frame_w-60 20], ...
		"fontname",defaultfont, "fontunits","points", ...
		"fontsize",16, "horizontalalignment","center", ...
		"background",[1 1 1], "tag","title_frame_control");
	// -------------------------
	// Step : Populate the frame
	// -------------------------
	// Adding model parameters
	guih1 = frame_w;
	guih1o = 240;
	// ordered list of labels
	labels1 = ["alpha0", "alpha", "n", "beta"];
	// ordered list of default values
	values1 = [1, 1000, 2.0, 5];
	// positioning
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels1,2)
		uicontrol("parent",demo_lhy, "style","text",...
			"string",labels1(k), "position",[l1,guih1-k*20+guih1o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry1(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values1(k)), "position",[l3,guih1-k*20+guih1o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels1(k));
	end
	// Adding simulation paramters
	guih2 = 240;
	guih2o = 80;
	labels2 = ["Tbegin", "Tend", "Tstep"];
	values2 = ["0", "15", "0.1"];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels2,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels2(k), "position",[l1,guih2-k*20+guih2o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
	
		guientry2(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",values2(k), "position",[l3,guih2-k*20+guih2o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels2(k));
	end
	// Adding initial conditions
	guih3 = 150;
	guih3o = 80;
	labels3 = ["A0", "B0", "C0", "D0", "E0", "F0"];
	values3 = [0, 1, 0, 2, 0, 5];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels3,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels3(k), "position",[l1,guih3-k*20+guih3o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry3(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values3(k)), "position",[l3,guih3-k*20+guih3o,180,20], ...
			"horizontalalignment","left", "fontsize",14,...
			"background",[.9 .9 .9], "tag",labels3(k));
	end
	// Adding button
	huibutton = uicontrol(demo_lhy, "style","pushbutton", ...
		"Position",[110 80 100 20], "String","Compute", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",14, ...
		"Callback","syscompute");

	// Compute solution
	sol = solvingProblem(param, sim);

	// Redraw window
	drawlater();
	newaxes();
	displayProblem(sol);
	drawnow();
endfunction

function syscompute
	// retrive data
	param = [];
	alpha0 = findobj("tag", "alpha0");		param.alpha0 = evstr(alpha0.string);
	alpha = findobj("tag", "alpha");			param.alpha = evstr(alpha.string);
	n = findobj("tag", "n");			param.n = evstr(n.string);
	beta = findobj("tag", "beta");			param.beta = evstr(beta.string);

	sim = [];
	Tbegin = findobj("tag", "Tbegin");sim.Tbegin = evstr(Tbegin.string);
	Tend = findobj("tag", "Tend");	sim.Tend = evstr(Tend.string);
	Tstep = findobj("tag", "Tstep");	sim.Tstep = evstr(Tstep.string);
	A0 = findobj("tag", "A0");			sim.A0 = evstr(A0.string);
	B0 = findobj("tag", "B0");			sim.B0 = evstr(B0.string);
	C0 = findobj("tag", "C0");			sim.C0 = evstr(C0.string);
	D0 = findobj("tag", "D0");			sim.D0 = evstr(D0.string);
	E0 = findobj("tag", "E0");			sim.E0 = evstr(E0.string);
	F0 = findobj("tag", "F0");			sim.F0 = evstr(F0.string);

	// Update fields
	updateFields(param, sim);
	
	// Compute solution
	sol = solvingProblem(param, sim);

	// Redraw window
	drawlater();
	my_plot_axes = gca();
	my_plot_axes.title.text = "Repressilator dengan keadaan oscillatory solution";
	newaxes();
	displayProblem(sol);
	drawnow();
endfunction

function sol = solvingProblem(param, sim)
	// Compute the solution
	sol = struct();

	// Assign ODE solver data
	y0 = [sim.A0;sim.B0;sim.C0;sim.D0;sim.E0;sim.F0];
	t0 = sim.Tbegin;
	t = sim.Tbegin:sim.Tstep:(sim.Tend+100*%eps);
	f = RepressilatorB2_System;

	// Solving the system
	sol.ABCDEF = ode("rk", y0, t0, t, f);
	sol.t = t;
endfunction

function displayProblem(solh)   
	// Fetching solution
	ABCDEF = sol.ABCDEF;
	t = sol.t;
	A = ABCDEF(1,:); B = ABCDEF(2,:); C = ABCDEF(3,:); D = ABCDEF(4,:); E = ABCDEF(5,:); F = ABCDEF(6,:);

	// Plotting of model data
	delete(gca());
	plot(ABCDEF(3,:),ABCDEF(4,:));
	//legend(['m1','p1','m2','p2','m3','p3','Location','NorthWest']);

	xlabel('Amount of solution m2');
    ylabel('Amount of solution p2');
	set(gca(),"auto_clear","on");

	my_plot_axes = gca();
	my_plot_axes.title.font_size = 5;
	my_plot_axes.axes_bounds = [1/3,0,2/3,1];
	my_plot_axes.title.text = "Repressilator dengan keadaan oscillatory solution";
endfunction

function LHY_About()
    msg = msprintf(gettext("Graf menunjukkan simulasi Biological Circuit of Repressilator dengan keadaan oscillatory solution"));
	messagebox(msg, gettext("About"), "info", "modal");
endfunction

function updateFields(param, sim)
	global gparam gsim pf sf
	
	// Loop over gparam/param elements
	for i=1:size(pf,1)
		// Get current field
		cf = pf(i);
		// check if they are different
		checkequal = 0;
		if(abs(gparam(cf)-param(cf))<= 1e-12) then
			checkequal = 1;
		end
		// Find object
		obj = findobj("tag", cf);
		if(isempty(obj)) then
			// object not found, skip, some problems?
			continue;
		end
		// Colorize
		if(~checkequal) then
			// Object is modified: use new color
			obj.BackgroundColor = [0.98 0.83 0.71];
		else
			// Object is not modified: use default color
			obj.BackgroundColor = [.9 .9 .9];
		end
	end
	
	// The same code for the field gsim/sim
	for i=1:size(sf,1)
		// Get current field
		cf = sf(i);
		// check if they are differents
		checkequal = 0;
		if(abs(gsim(cf)-sim(cf))<= 1e-12) then
			checkequal = 1;
		end
		// Find object
		obj = findobj("tag", cf);
		if(isempty(obj)) then
			// object not found, skip, some problems?
			continue;
		end
		// Colorize
		if(~checkequal) then
			// Object is modified: use new color
			obj.BackgroundColor = [0.98 0.83 0.71];
		else
			// Object is not modied: use default color
			obj.BackgroundColor = [.9 .9 .9];
		end
	end
endfunction
