function [] = RepressilatorC3_Gui()
	// ----------------------------
	// Step : Empty window creation
	// ----------------------------
	
	// Global window parameters
	global margin_x margin_y;
	global frame_w frame_h plot_w plot_h;

	// Window Parameters initialization
	frame_w = 300; frame_h = 550;		// Frame width and height
	plot_w = 600; plot_h = frame_h;	// Plot width and heigh
	margin_x = 15; margin_y = 15;		// Horizontal and vertical margin for elements
	defaultfont = "arial"; 			// Default Font
	axes_w = 3*margin_x + frame_w + plot_w;	// axes width
	axes_h = 2*margin_y + frame_h;          	// axes height (100 => toolbar height)
	demo_lhy = scf(100001);			// Create window with id=100001 and make it the current one
	
	// Background and text
	demo_lhy.background      = -2;
	demo_lhy.figure_position = [100 100];
	demo_lhy.figure_name     = gettext("Biological Circuit of Repressilator");
	
	// Change dimensions of the figure
	demo_lhy.axes_size = [axes_w axes_h];
	
	// ------------------
	// Step : Window menu
	// ------------------
	
	// Remove Scilab graphics menus & toolbar
	delmenu(demo_lhy.figure_id,gettext("&File"));
	delmenu(demo_lhy.figure_id,gettext("&Tools"));
	delmenu(demo_lhy.figure_id,gettext("&Edit"));
	delmenu(demo_lhy.figure_id,gettext("&?"));
	toolbar(demo_lhy.figure_id,"off");

	// New menu
	h1 = uimenu("parent",demo_lhy, "label",gettext("File"));
	h2 = uimenu("parent",demo_lhy, "label",gettext("About"));
	
	// Populate menu: file
	uimenu("parent",h1, "label",gettext("Close"), "callback", "demo_lhy=get_figure_handle(100001);delete(demo_lhy);", "tag","close_menu");
	
	// Populate menu: about
	uimenu("parent",h2, "label",gettext("About"), "callback","LHY_About();");
	// Sleep to guarantee a better display (avoiding to see a sequential display)
	sleep(500);
   
   displayProblem()
   
endfunction

function ydot=repressilator2(t,y,p)
    alpha0 = p(1);
    n = p(2);
    beta = p(3);
    alpha = p(4);
    //order of species; y = [m1 p1 m2 p2 m3 p3]
    m1 = -y(1) + alpha/(1+y(6)^n) + alpha0;
    p1 = -beta*(y(2)-y(1));
    m2 = -y(3) + alpha/(1+y(2)^n) + alpha0;
    p2 = -beta*(y(4)-y(3));
    m3 = -y(5) + alpha/(1+y(4)^n) + alpha0;
    p3 = -beta*(y(6)-y(5));
    ydot = [m1; p1; m2; p2; m3; p3];
endfunction


function displayProblem(ydot)   
t=0:0.1:15;
t0=0;
y0=[0; 1; 0; 2; 0; 3];
params1 = [1 1.75 5 5];
params2 = [1 1.75 5 28];
params3 = [1 1.75 5 1000];
//y = ode("fix",y0,t0,t,params1,repressilator2)
y1 = ode("rk",y0,t0,t,list(repressilator2,params1));
y2 = ode("rk",y0,t0,t,list(repressilator2,params2));
y3 = ode("rk",y0,t0,t,list(repressilator2,params3));

subplot(3,1,1)
plot(y1(5,:),y1(6,:))
ylabel('Amount p3')
title("Perubahan tingkah laku repressilator solutions")
subplot(3,1,2)
plot(y2(5,:),y2(6,:))
ylabel('Amount p3')
subplot(3,1,3)
plot(y3(5,:),y3(6,:))
xlabel('Time')
ylabel('Amount m3')

	my_plot_axes = gca();
	my_plot_axes.title.font_size = 5;
	//my_plot_axes.axes_bounds = [1/3,0,2/3,1];
	
endfunction

function LHY_About()
    msg = msprintf(gettext("Graf menunjukkan simulasi Biological Circuit of Repressilator dengan Perubahan tingkah laku repressilator solutions"));
	messagebox(msg, gettext("About"), "info", "modal");
endfunction
