function [] = ToggleC2_new_Gui()
    // Default simulation parameters
	param = [];
	param.ktr   = 3.17;      
	param.ktrans     = 2.85;     
	param.yp     = 2.13*(10^(-2));    
	param.ym  = 0.19;      
	param.Ks     = 1000;
    param.Kd     = 0.05;    
	param.DNA     = 150;    
	param.n1     = 2;    
	param.n2 = 2;    
    param.Repressor = 3.5*(10^5);
    param.Inducer = 0;

	// Simulation data
	// Time variables
	sim = [];
	sim.Tbegin = 0;          // Initial time
	sim.Tend   = 200;          // Final time
	sim.Tstep  = 0.1;          // Time step
	// Initial conditions
	sim.A0 = 0;             
	sim.B0 = 0;            
	sim.C0 = 0;

//Assume the the repressor is removed at t=0

t = 0:0.1:200;//Set time span

ktr = param.ktr;
ktrans = param.ktrans;
yp = param.yp;
ym = param.ym;
Ks = param.Ks;
Kd = param.Kd;
DNA = param.DNA;
n1 = param.n1;
n2 = param.n2;
Repressor = param.Repressor;
Inducer = param.Inducer;

//Calculate mRNA and Protein values
K = (ktr*DNA)/(1+(Repressor/((1+(Inducer/Ks)^n2)*Kd))^n1);
mRNA = K/ym+(2.5*(10^3)-K/ym)*exp(-ym*t);

	// global default data
	global gparam gsim pf sf;
	gparam = param;
	gsim = sim;
	// param and sim fields
	pf = fieldnames(gparam);	// param fields
	sf = fieldnames(gsim);		// sim fields
	
	// ----------------------------
	// Step : Empty window creation
	// ----------------------------
	
	// Global window parameters
	global margin_x margin_y;
	global frame_w frame_h plot_w plot_h;

	// Window Parameters initialization
	frame_w = 300; frame_h = 550;		// Frame width and height
	plot_w = 600; plot_h = frame_h;	// Plot width and heigh
	margin_x = 15; margin_y = 15;		// Horizontal and vertical margin for elements
	defaultfont = "arial"; 			// Default Font
	axes_w = 3*margin_x + frame_w + plot_w;	// axes width
	axes_h = 2*margin_y + frame_h;          	// axes height (100 => toolbar height)
	demo_lhy = scf(100001);			// Create window with id=100001 and make it the current one
	
	// Background and text
	demo_lhy.background      = -2;
	demo_lhy.figure_position = [100 100];
	demo_lhy.figure_name     = gettext("Genetic Toggle Switch");
	
	// Change dimensions of the figure
	demo_lhy.axes_size = [axes_w axes_h];
	
	// ------------------
	// Step : Window menu
	// ------------------
	
	// Remove Scilab graphics menus & toolbar
	delmenu(demo_lhy.figure_id,gettext("&File"));
	delmenu(demo_lhy.figure_id,gettext("&Tools"));
	delmenu(demo_lhy.figure_id,gettext("&Edit"));
	delmenu(demo_lhy.figure_id,gettext("&?"));
	toolbar(demo_lhy.figure_id,"off");

	// New menu
	h1 = uimenu("parent",demo_lhy, "label",gettext("File"));
	h2 = uimenu("parent",demo_lhy, "label",gettext("About"));
	
	// Populate menu: file
	uimenu("parent",h1, "label",gettext("Close"), "callback", "demo_lhy=get_figure_handle(100001);delete(demo_lhy);", "tag","close_menu");
	
	// Populate menu: about
	uimenu("parent",h2, "label",gettext("About"), "callback","LHY_About();");
	// Sleep to guarantee a better display (avoiding to see a sequential display)
	sleep(500);
   
	// ---------------------
	// Step : Create a frame
	// ---------------------
	
	// Frames creation [LHY parameters]
	my_frame = uicontrol("parent",demo_lhy, "relief","groove", ...
		"style","frame", "units","pixels", ...
		"position",[ margin_x margin_y frame_w frame_h], ...
		"horizontalalignment","center", "background",[1 1 1], ...
		"tag","frame_control");

	// Frame title
	my_frame_title = uicontrol("parent",demo_lhy, "style","text", ...
		"string","Toggle Switch parameters", "units","pixels", ...
		"position",[30+margin_x margin_y+frame_h-10 frame_w-60 20], ...
		"fontname",defaultfont, "fontunits","points", ...
		"fontsize",16, "horizontalalignment","center", ...
		"background",[1 1 1], "tag","title_frame_control");
	// -------------------------
	// Step : Populate the frame
	// -------------------------
	// Adding model parameters
	guih1 = frame_w;
	guih1o = 240;
	// ordered list of labels
	labels1 = ["ktr", "ktrans", "yp", "ym", "Ks", "Kd", "DNA", "n1", "n2", "Repressor", "Inducer"];
	// ordered list of default values
	values1 = [3.17, 2.85, 2.13*(10^(-2)), 0.19, 1000, 0.05, 150, 2, 2, 3.5*(10^5), 0];
	// positioning
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels1,2)
		uicontrol("parent",demo_lhy, "style","text",...
			"string",labels1(k), "position",[l1,guih1-k*20+guih1o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry1(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values1(k)), "position",[l3,guih1-k*20+guih1o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels1(k));
	end
	// Adding simulation paramters
	guih2 = 240;
	guih2o = 80;
	labels2 = ["Tbegin", "Tend", "Tstep"];
	values2 = ["0", "200", "0.1"];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels2,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels2(k), "position",[l1,guih2-k*20+guih2o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
	
		guientry2(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",values2(k), "position",[l3,guih2-k*20+guih2o,180,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[.9 .9 .9], "tag",labels2(k));
	end
	// Adding initial conditions
	guih3 = 150;
	guih3o = 80;
	labels3 = ["A0", "B0", "C0"];
	values3 = [0, 0, 0];
	l1 = 40; l2 = 100; l3 = 110;
	for k=1:size(labels3,2)
		uicontrol("parent",demo_lhy, "style","text", ...
			"string",labels3(k), "position",[l1,guih3-k*20+guih3o,l2,20], ...
			"horizontalalignment","left", "fontsize",14, ...
			"background",[1 1 1]);
     
		guientry3(k) = uicontrol("parent",demo_lhy, "style","edit", ...
			"string",string(values3(k)), "position",[l3,guih3-k*20+guih3o,180,20], ...
			"horizontalalignment","left", "fontsize",14,...
			"background",[.9 .9 .9], "tag",labels3(k));
	end

displayProblem();

endfunction

function displayProblem()   
	// Fetching solution

plot(t,mRNA,"r","LineWidth",2)
set(gca(),"auto_clear","off")
ym = 0.38;//Change mRNA degradation rate
mRNA = K/ym+(2.5*(10^3)-K/ym)*exp(-ym*t);
plot(t,mRNA,"b","LineWidth",2)
ym = 1.9;//Change mRNA degradation rate
mRNA = K/ym+(2.5*(10^3)-K/ym)*exp(-ym*t);
plot(t,mRNA,"g","LineWidth",2)
xlabel("Time (minutes)")
ylabel("Number of mRNA per Cell")
//title("mRNA Expression with varrying \gamma_m")
legend("gamma_m=0.19 min^-1","gamma_m=0.38 min^-1","gamma_m=1.9 min^-1")

	my_plot_axes = gca();
	my_plot_axes.title.font_size = 5;
	my_plot_axes.axes_bounds = [1/3,0,2/3,1];
	my_plot_axes.title.text = "mRNA Expression with varrying gamma_m";
endfunction

function LHY_About()
    msg = msprintf(gettext("Graf menunjukkan simulasi Genetic Toggle Switch di mana membina semula kes analisis di mana menganggap repressor ditambah pada t = 0"));
	messagebox(msg, gettext("About"), "info", "modal");
endfunction
